============
Contributing
============

PyScaffold is developed by Blue Yonder developers to help automating and
standardizing the process of project setups.
You are very welcome to join in our effort if you would like to contribute.

Bug Reports
===========

If you experience bugs or in general issues with PyScaffold, please file a bug
report to our `Bug Tracker <http://github.com/blue-yonder/pyscaffold/issues>`_.


Code
====

If you would like to contribute to PyScaffold, fork the `main repository
<https://github.com/blue-yonder/pyscaffold/>`_ on GitHub, then submit a
“pull request” (PR):

#. `Create an account <https://github.com/signup/free>`_ on GitHub if you do
   not already have one.
#. Fork the project repository: click on the *Fork* button near the top of the
   page. This creates a copy of the code under your account on the GitHub server.
#. Clone this copy to your local disk::

    git clone git@github.com:YourLogin/pyscaffold.git

#. Create a branch to hold your changes::

    git checkout -b my-feature

   and start making changes. Never work in the master branch!

#. Work on this copy, on your computer, using `Git <http://git-scm.com/>`_ to
   do the version control. When you’re done editing, do::

    git add modified_files
    git commit

   to record your changes in Git, then push them to GitHub with::

    git push -u origin my-feature
